@@ -20,9 +20,10 @@
 mf_layout <- function(title = "Map Title",
                       credits = "Authors & Sources",
                       scale = TRUE, arrow = TRUE, frame = FALSE) {
-  op <- par(mar = .gmapsf$args$mar, no.readonly = TRUE)
+  test_cur_plot()
+  op <- par(mar = getOption("mapsf.mar"), no.readonly = TRUE)
   on.exit(par(op))
-  fg <- .gmapsf$args$fg
+  fg <- getOption("mapsf.fg")
 
   if (title != "") {
     mf_title(txt = title)
