@@ -14,7 +14,7 @@
 #' mf_map(mtq, add = TRUE)
 mf_shadow <- function(x, col = "grey50", cex = 1, add = FALSE) {
   if (add == FALSE) {
-    mf_map(x, type = "base", col = NA, border = NA)
+    mf_init(x)
   }
   d <- cex * strwidth("M", units = "user", cex = 1) / 3
   z <- st_geometry(x) + c(d, -d)
